Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const core = require('@sentry/core');
const node = require('@sentry/node');
const debugBuild = require('../utils/debug-build.js');
const instrumentServer = require('./instrumentServer.js');
const http = require('./integrations/http.js');
const opentelemetry = require('./integrations/opentelemetry.js');

/**
 * Returns the default Remix integrations.
 *
 * @param options The options for the SDK.
 */
function getRemixDefaultIntegrations(options) {
  return [
    ...node.getDefaultIntegrations(options ).filter(integration => integration.name !== 'Http'),
    http.httpIntegration(),
    opentelemetry.remixIntegration(),
  ].filter(int => int) ;
}

/** Initializes Sentry Remix SDK on Node. */
function init(options) {
  core.applySdkMetadata(options, 'remix', ['remix', 'node']);

  if (node.isInitialized()) {
    debugBuild.DEBUG_BUILD && core.logger.log('SDK already initialized');

    return;
  }

  options.defaultIntegrations = getRemixDefaultIntegrations(options );

  const client = node.init(options );

  instrumentServer.instrumentServer();

  return client;
}

exports.getRemixDefaultIntegrations = getRemixDefaultIntegrations;
exports.init = init;
//# sourceMappingURL=sdk.js.map
