import { applySdkMetadata, logger } from '@sentry/core';
import { isInitialized, init as init$1, getDefaultIntegrations } from '@sentry/node';
import { DEBUG_BUILD } from '../utils/debug-build.js';
import { instrumentServer } from './instrumentServer.js';
import { httpIntegration } from './integrations/http.js';
import { remixIntegration } from './integrations/opentelemetry.js';

/**
 * Returns the default Remix integrations.
 *
 * @param options The options for the SDK.
 */
function getRemixDefaultIntegrations(options) {
  return [
    ...getDefaultIntegrations(options ).filter(integration => integration.name !== 'Http'),
    httpIntegration(),
    remixIntegration(),
  ].filter(int => int) ;
}

/** Initializes Sentry Remix SDK on Node. */
function init(options) {
  applySdkMetadata(options, 'remix', ['remix', 'node']);

  if (isInitialized()) {
    DEBUG_BUILD && logger.log('SDK already initialized');

    return;
  }

  options.defaultIntegrations = getRemixDefaultIntegrations(options );

  const client = init$1(options );

  instrumentServer();

  return client;
}

export { getRemixDefaultIntegrations, init };
//# sourceMappingURL=sdk.js.map
