import { ActionFunction, ActionFunctionArgs, EntryContext, HandleDocumentRequestFunction, LoaderFunction, LoaderFunctionArgs } from '@remix-run/node';
import { Span } from '@sentry/core';
type DataFunction = LoaderFunction | ActionFunction;
/**
 * Captures an exception happened in the Remix server.
 *
 * @param err The error to capture.
 * @param name The name of the origin function.
 * @param request The request object.
 *
 * @returns A promise that resolves when the exception is captured.
 */
export declare function captureRemixServerException(err: unknown, name: string, request: Request): Promise<void>;
/**
 * Wraps the original `HandleDocumentRequestFunction` with error handling.
 *
 * @param origDocumentRequestFunction The original `HandleDocumentRequestFunction`.
 * @param requestContext The request context.
 *
 * @returns The wrapped `HandleDocumentRequestFunction`.
 */
export declare function errorHandleDocumentRequestFunction(this: unknown, origDocumentRequestFunction: HandleDocumentRequestFunction, requestContext: {
    request: Request;
    responseStatusCode: number;
    responseHeaders: Headers;
    context: EntryContext;
    loadContext?: Record<string, unknown>;
}): HandleDocumentRequestFunction;
/**
 * Wraps the original `DataFunction` with error handling.
 * This function also stores the form data keys if the action is being called.
 *
 * @param origFn The original `DataFunction`.
 * @param name The name of the function.
 * @param args The arguments of the function.
 * @param span The span to store the form data keys.
 *
 * @returns The wrapped `DataFunction`.
 */
export declare function errorHandleDataFunction(this: unknown, origFn: DataFunction, name: string, args: ActionFunctionArgs | LoaderFunctionArgs, span?: Span): Promise<Response>;
export {};
//# sourceMappingURL=errors.d.ts.map
